RAMP examples
=============

.. toctree::
    :maxdepth: 2

    examples/simple_bulb/simple_bulb
    examples/fixed_flat_app/fixed_flat_app
    examples/occasional_use/occasional_use
    examples/multi_cycle/multi_cycle
    examples/cooking_app/cooking_app
    examples/using_excel/using_excel
    examples/thermal_app/thermal_app
    examples/year_simulation/year_simulation
    examples/parallel_processing/parallel_processing
